@@ -21,20 +21,20 @@ test_that("Checking dmvn() and maha() against dmvnorm() and mahalanobis", {
     ##### dmvn()
     bench <- dmvnorm(X, mu, mcov, log = T)
     # Sequential
-    expect_less_than(sum(abs(dmvn(X, mu, mcov, log = T) - bench)), 1e-6)
-    expect_less_than(sum(abs(dmvn(X, mu, myChol, isChol = TRUE, log = T) - bench)), 1e-6)
+    expect_lt(sum(abs(dmvn(X, mu, mcov, log = T) - bench)), 1e-6)
+    expect_lt(sum(abs(dmvn(X, mu, myChol, isChol = TRUE, log = T) - bench)), 1e-6)
     # Parallel
-    expect_less_than(sum(abs(dmvn(X, mu, mcov, ncores = 2, log = T) - bench)), 1e-6)
-    expect_less_than(sum(abs(dmvn(X, mu, myChol, ncores = 2, isChol = TRUE, log = T) - bench)), 1e-6)
+    expect_lt(sum(abs(dmvn(X, mu, mcov, ncores = 2, log = T) - bench)), 1e-6)
+    expect_lt(sum(abs(dmvn(X, mu, myChol, ncores = 2, isChol = TRUE, log = T) - bench)), 1e-6)
     
     ##### maha()
     bench <- mahalanobis(X, mu, mcov)
     # Sequential
-    expect_less_than(sum(abs(maha(X, mu, mcov) - bench)), 1e-6)
-    expect_less_than(sum(abs(maha(X, mu, myChol, isChol = TRUE) - bench)), 1e-6)
+    expect_lt(sum(abs(maha(X, mu, mcov) - bench)), 1e-6)
+    expect_lt(sum(abs(maha(X, mu, myChol, isChol = TRUE) - bench)), 1e-6)
     # Parallel
-    expect_less_than(sum(abs(maha(X, mu, mcov, ncores = 2) - bench)), 1e-6)
-    expect_less_than(sum(abs(maha(X, mu, myChol, ncores = 2, isChol = TRUE) - bench)), 1e-6)
+    expect_lt(sum(abs(maha(X, mu, mcov, ncores = 2) - bench)), 1e-6)
+    expect_lt(sum(abs(maha(X, mu, myChol, ncores = 2, isChol = TRUE) - bench)), 1e-6)
     
     message(paste("Test", ii, "passed."))
   }
